Suppose you want to map images you took over the years.

You follow a simple plan:

- extract data (filename + exif for latitude and logitude)
- put those into the `pic` schema
- map them with leaflet

The following was tested on photos of my Galaxy S7 phone.

See [felix/exif README](../puddl/felix/exif/README.md).

Start stupid and schemaless:
```
cd puddl/felix/exif/
./load.py
# open pycharm, run SQL against the exif schema xD
./generate.py > data.js
```
